@@ -1,7 +1,7 @@
   package HO::class
 # *****************
 ; use strict; use warnings;
-  our $VERSION='0.075';
+  our $VERSION='0.076';
 # ********************
 
 ; require HO::accessor
@@ -112,10 +112,10 @@
       ; while(@lvalue)
           { my $name = shift(@lvalue)
           ; my $acc = "_$name"
-          ; my $idx = HO::accessor::_value_of($class, $acc)
+          # lvalue methods are inherited not copied, so they needs to have dynamic index
           ; *{join('::',$class,$name)} = sub : lvalue
                { my $self = shift();
-               ; $self->[$idx]
+               ; $self->[$self->$acc]
                }
           }
       ; while(my ($name,$subdata) = splice(@r_,0,2))
